starcluster.templates.config

Package starcluster :: Package templates :: Module config |
[hide private]
[frames] | no frames]

# Module config

source code

Variables | [hide private]
| config_template = ``'``\n####################################\n##` `...``
| DASHES = ``'``----------``'``
| copy_paste_template = ``'``---------- COPY BELOW THIS LINE -------``...``
| __package__ = ``'``starcluster.templates``'``

Variables Details | [hide private]

  ### config_template Value:
      '''
      ####################################
      ## StarCluster Configuration File ##
      ####################################

      [global]
      # configure the default cluster template to use when starting a cluste
      r
      ...

  ### copy_paste_template Value:
      '''---------- COPY BELOW THIS LINE ----------

      ####################################
      ## StarCluster Configuration File ##
      ####################################

      [global]
      # configure the default cluster template to use when starting a cluste
      ...